{
    "$graph": [
        {
            "class": "CommandLineTool",
            "doc": "This CWL description of the iseq downloader tool doesn't require the user to\nconstruct a \".iseq\" credentials file; it assembles the credentials file for\nthem.\n",
            "requirements": [
                {
                    "listing": [
                        {
                            "entryname": ".iseq",
                            "entry": "analyzer:$(inputs.username):$(inputs.password):$(inputs.url)\n"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "airr-seqaa",
                    "class": "DockerRequirement"
                },
                {
                    "secrets": [
                        "password"
                    ],
                    "class": "http://commonwl.org/cwltool#Secrets"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#downloader2.cwl/password"
                },
                {
                    "type": "string",
                    "label": "project UUID, or name within the given 'workspace'",
                    "id": "#downloader2.cwl/project"
                },
                {
                    "type": "File",
                    "label": "SQL query to run",
                    "id": "#downloader2.cwl/query"
                },
                {
                    "type": "string",
                    "default": "https://analyzer.adaptivebiotech.com",
                    "id": "#downloader2.cwl/url"
                },
                {
                    "type": "string",
                    "id": "#downloader2.cwl/username"
                },
                {
                    "type": "string",
                    "label": "workspace UUID or name",
                    "id": "#downloader2.cwl/workspace"
                }
            ],
            "baseCommand": "iseq",
            "stdin": "$(inputs.query.path)",
            "arguments": [
                "analyzer",
                "$(inputs.workspace)",
                "$(inputs.project)"
            ],
            "stdout": "$(inputs.project).tsv",
            "id": "#downloader2.cwl",
            "outputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.project).tsv"
                    },
                    "id": "#downloader2.cwl/results"
                }
            ]
        },
        {
            "class": "Workflow",
            "hints": [
                {
                    "secrets": [
                        "password"
                    ],
                    "class": "http://commonwl.org/cwltool#Secrets"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/mapping"
                },
                {
                    "type": "string",
                    "id": "#main/password"
                },
                {
                    "type": "string",
                    "label": "project UUID, or name within the given 'workspace'",
                    "id": "#main/project"
                },
                {
                    "type": "File",
                    "label": "SQL query to run",
                    "id": "#main/query"
                },
                {
                    "type": "File",
                    "id": "#main/tags"
                },
                {
                    "type": "string",
                    "id": "#main/username"
                },
                {
                    "type": "string",
                    "label": "workspace UUID or name",
                    "id": "#main/workspace"
                }
            ],
            "steps": [
                {
                    "run": "#tsv_to_json.cwl",
                    "in": [
                        {
                            "source": "#main/map_adaptive_to_AIRR/results",
                            "id": "#main/convert_to_AIRR_Repertoire_JSON/tsv"
                        }
                    ],
                    "out": [
                        "#main/convert_to_AIRR_Repertoire_JSON/json"
                    ],
                    "id": "#main/convert_to_AIRR_Repertoire_JSON"
                },
                {
                    "run": "#downloader2.cwl",
                    "in": [
                        {
                            "source": "#main/password",
                            "id": "#main/download_adaptive_study/password"
                        },
                        {
                            "source": "#main/project",
                            "id": "#main/download_adaptive_study/project"
                        },
                        {
                            "source": "#main/query",
                            "id": "#main/download_adaptive_study/query"
                        },
                        {
                            "source": "#main/username",
                            "id": "#main/download_adaptive_study/username"
                        },
                        {
                            "source": "#main/workspace",
                            "id": "#main/download_adaptive_study/workspace"
                        }
                    ],
                    "out": [
                        "#main/download_adaptive_study/results"
                    ],
                    "id": "#main/download_adaptive_study"
                },
                {
                    "run": "#mapping.cwl",
                    "in": [
                        {
                            "source": "#main/mapping",
                            "id": "#main/map_adaptive_to_AIRR/mapping"
                        },
                        {
                            "source": "#main/project",
                            "id": "#main/map_adaptive_to_AIRR/study_id"
                        },
                        {
                            "source": "#main/tags",
                            "id": "#main/map_adaptive_to_AIRR/tags"
                        },
                        {
                            "source": "#main/download_adaptive_study/results",
                            "id": "#main/map_adaptive_to_AIRR/tsv"
                        }
                    ],
                    "out": [
                        "#main/map_adaptive_to_AIRR/results"
                    ],
                    "id": "#main/map_adaptive_to_AIRR"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/application/json",
                    "outputSource": "#main/convert_to_AIRR_Repertoire_JSON/json",
                    "id": "#main/results"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "airr-seqaa",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#mapping.cwl/mapping"
                },
                {
                    "type": "string",
                    "id": "#mapping.cwl/study_id"
                },
                {
                    "type": "File",
                    "id": "#mapping.cwl/tags"
                },
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "id": "#mapping.cwl/tsv"
                }
            ],
            "baseCommand": "parser_.py",
            "arguments": [
                "$(inputs.tsv.path)",
                "$(inputs.mapping.path)",
                "$(inputs.tags.path)",
                "$(inputs.study_id)"
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "$(inputs.tsv.format)",
                    "outputBinding": {
                        "glob": "$(inputs.study_id).tsv"
                    },
                    "id": "#mapping.cwl/results"
                }
            ],
            "id": "#mapping.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Based upon scripts/tsv_to_json.py by Artem Kushner, Laura Gutierrez Funderburk",
            "hints": [
                {
                    "dockerPull": "airr-seqaa",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "id": "#tsv_to_json.cwl/tsv"
                }
            ],
            "baseCommand": [
                "python3",
                "-c"
            ],
            "arguments": [
                "import pandas as pd\ndataframe = pd.read_csv(\"$(inputs.tsv.path)\", sep='\\t')\nwith open(\"$(inputs.tsv.nameroot).json\", 'w') as f:\n  f.write(dataframe.to_json(orient='records'))\n"
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/application/json",
                    "outputBinding": {
                        "glob": "$(inputs.tsv.nameroot).json"
                    },
                    "id": "#tsv_to_json.cwl/json"
                }
            ],
            "id": "#tsv_to_json.cwl"
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "iana": "https://www.iana.org/assignments/media-types/",
        "cwltool": "http://commonwl.org/cwltool#"
    }
}
